@@ -101,9 +101,9 @@ class Reader:
         self._file = file
         self._only_detect_source = only_detect_source
         self._resources = resources
-        self._rsids = rsids
+        self._rsids = frozenset(rsids)
 
-    def __call__(self):
+    def read(self):
         """ Read and parse a raw data / genotype file.
 
         Returns
@@ -222,7 +222,7 @@ class Reader:
                 flag indicating if SNPs are phased
         """
         r = cls(file, only_detect_source, resources, rsids)
-        return r()
+        return r.read()
 
     def _extract_comments(self, f, decode=False, include_data=False):
         line = self._read_line(f, decode)
@@ -566,35 +566,19 @@ class Reader:
         """
 
         def parser():
-            try:
-                df = pd.read_csv(
-                    file,
-                    comment="#",
-                    header=0,
-                    sep="\t",
-                    na_values=0,
-                    names=["rsid", "chrom", "pos", "allele1", "allele2"],
-                    index_col=0,
-                    dtype=TWO_ALLELE_DTYPES,
-                    compression=compression,
-                )
-            except ValueError:
-                if isinstance(file, io.BytesIO):
-                    file.seek(0)
-
-                # read files with multiple separators
-                df = pd.read_csv(
-                    file,
-                    comment="#",
-                    header=0,
-                    sep=r"\s+|\t+|\s+\t+|\t+\s+",  # https://stackoverflow.com/a/41320761
-                    engine="python",
-                    na_values=0,
-                    names=["rsid", "chrom", "pos", "allele1", "allele2"],
-                    index_col=0,
-                    dtype=TWO_ALLELE_DTYPES,
-                    compression=compression,
-                )
+            df = pd.read_csv(
+                file,
+                comment="#",
+                header=0,
+                engine="c",
+                sep="\s+",
+                # delim_whitespace=True,  # https://stackoverflow.com/a/15026839
+                na_values=0,
+                names=["rsid", "chrom", "pos", "allele1", "allele2"],
+                index_col=0,
+                dtype=TWO_ALLELE_DTYPES,
+                compression=compression,
+            )
 
             # create genotype column from allele columns
             df["genotype"] = df["allele1"] + df["allele2"]
@@ -1118,11 +1102,18 @@ class Reader:
         with io.TextIOWrapper(io.BufferedReader(f)) as file:
 
             for line in file:
-
                 line_strip = line.strip("\n")
+
+                # skip blank lines
+                if not line_strip:
+                    continue
+
+                # skip comment lines
                 if line_strip.startswith("#"):
                     continue
+
                 rsid = line_strip.split("\t")[2]
+
                 # skip SNPs with missing rsIDs.
                 if rsid == ".":
                     continue
@@ -1161,7 +1152,7 @@ class Reader:
                         genotype = np.nan
                         break
                     z = int(z)
-                    if z > len(ref_alt):
+                    if z >= len(ref_alt):
                         # invalid genotype number
                         genotype = np.nan
                         break
